@@ -21,7 +21,8 @@ for i in data:
             continue
     if rev and summary and data:
         if 'Added tag' in summary:
-            print '\n%s\n' % summary.split()[2]
-        print "%s) %s .. %s" % (rev, date, summary)
+            print '\n%s' % summary.split()[2]
+            print '~' * len(summary.split()[2]) + '\n\n'
+        print "%s %s .. %s\n" % (rev, date, summary)
         date = rev = summary = ""
 
