@@ -10,7 +10,7 @@ host = 'localhost'
 port = 5500
 passwd = 'mekker'
 printto = '#dunkbots'
-seed = "bla1234567890bla"
+seed = "blablablablablaz"
 length = 16
 ipv6 = 0
 
