@@ -8,12 +8,12 @@
 from simplejson import loads
 
 try:
-    cmndtable = loads(open('cmndtable').read())
+    cmndtable = loads(open('gozerdata' + os.sep + 'run' + os.sep + 'cmndtable').read())
 except:
     cmndtable = {}
 
 try:
-    pluginlist = loads(open('pluginlist').read())
+    pluginlist = loads(open('gozerdata' + os.sep + 'run' + os.sep + 'pluginlist').read())
 except:
     pluginlist = []
 
