@@ -7,6 +7,7 @@
 # IMPORT SECTION
 
 # gozerbot imports
+from threads.thr import start_new_thread
 from utils.log import rlog
 from less import Less
 from persist.pdol import Pdol
@@ -19,18 +20,24 @@ from persist.pdod import Pdod
 from config import config, Config, fleetbotconfigtxt
 from runner import runners_start
 from monitor import Monitor
-from callbacks import callbacks
+from callbacks import callbacks, gn_callbacks
 from cache import userhosts
 from wait import Wait, Privwait
 from eventhandler import mainhandler
 from exit import globalshutdown
 from utils.exception import handle_exception
+from plugins import plugins
+
+# throttle support
+from gozerbot.plugs.throttle import state as throttlestate
 
 # basic imports
-import time, threading, os, types, sys, asyncore
+import time, threading, os, types, sys, copy
 
 # END IMPORT
 
+cpy = copy.deepcopy
+
 class BotBase(object):
 
     """ 
@@ -57,7 +64,7 @@ class BotBase(object):
            cfg['user'] = 'gozerbot'
 
         if not cfg.has_key('type'):
-           cfg['type'] = 'irc'
+           cfg['type'] = 'gozernet'
 
         # set attributes based on config 
         self.__dict__.update(cfg)
@@ -105,8 +112,9 @@ class BotBase(object):
         self.datadir = datadir + os.sep + 'fleet' + os.sep + self.name
 
         # set datadir to datadir/fleet/<botname>
-        if not os.path.exists(self.datadir):
-            os.mkdir(self.datadir)
+        if hasattr(os, 'mkdir'):
+            if not os.path.exists(self.datadir):
+                os.mkdir(self.datadir)
 
         # bot state
         self.state = Pdod(self.datadir + os.sep + 'state') # bot state
@@ -127,17 +135,22 @@ class BotBase(object):
         if not self.state.has_key('opchan'):
             self.state['opchan'] = []
 
+        # the time we joined a channel
+        self.timejoined = {}
+
         # jabber type doesnt exists anymore .. set type to 'xmpp' instead
-        self.type = self.type or 'irc'
+        self.type = self.type or 'gozernet'
+
         if self.type == 'jabber':
             self.type = 'xmpp'
 
         self.networkname = self.server
+        self.jid = "%s@%s" % (self.nick, self.server)
         self.jids = {}
         self.shutloop = False
         self.cfg = cfg # the bots config
         self.orignick = "" # original nick
-        self.blocking = True # use blocking sockets
+        self.blocking = 1 # use blocking sockets
         self.lastoutput = 0 # time of last output
         self.stopped = False # flag to set when bot is to be stopped
         self.connected = False # conencted flag
@@ -154,7 +167,14 @@ class BotBase(object):
         self.splitted = [] # list of splitted nicks
         self.throttle = [] # list of nicks that need to be throttled
         self.jabber = False # flag is set on jabber bots
-        self.google = False # flag is set on google bots
+        self.google = False
+        if 'google' in self.host:
+            self.google = True # flag is set on google bots
+        try:
+            import google.appengine.ext 
+            self.google = True
+        except:
+            pass
         self.callbacks = callbacks
         self.monitor = Monitor()
         self.wait = Wait()
@@ -223,7 +243,7 @@ class BotBase(object):
 
         pass
 
-    def say(self, printto, what, who=None, how='msg', fromm=None, speed=0, groupchat=False):
+    def say(self, printto, what, event=None, who=None, how='msg', fromm=None, speed=0, groupchat=False):
         print what
 
     def whois(self, nick):
@@ -268,13 +288,16 @@ class BotBase(object):
 
         while not self.stopped and not self.shutloop:
             try:
-                asyncore.poll(timeout=0.1)
-                time.sleep(0.5)
-                mainhandler.handle_one()
+                import asyncore
+                asyncore.poll(timeout=0.01)
+            except ImportError:
+                pass
             except Exception, ex:
                 handle_exception()
                 globalshutdown()
                 os._exit(1)
+            time.sleep(0.01)
+            mainhandler.handle_one()
 
     def join(self, channel, password=""):
         pass
@@ -291,7 +314,7 @@ class BotBase(object):
 
         self.connect(reconnect)
         self.connectok.wait()
-        self.joinchannels()
+        start_new_thread(self.joinchannels, ())
 
     def broadcast(self):
 
@@ -328,8 +351,44 @@ class BotBase(object):
              msg.reply('executing %s (%s) on %s bot' % (msg.txt, msg.userhost, self.name))
 
         from gozerbot.plugins import plugins
-
+        
         if wait:
             plugins.waitdispatch(self, msg)
         else:
             plugins.trydispatch(self, msg)
+
+    def ratelimit(self, userhost, cpm=20):
+        try:
+            throttlestate['level'][userhost] = cpm 
+            throttlestate.save()
+            rlog(10, self.name, '%s throttled to %s cpm' % (userhost, cpm))
+        except Exception, ex:
+            rlog(100, self.name, "can't set throttle of %s" % userhost)
+            handle_exception()
+
+    def remoteout(self, request, event):
+        request.wfile.write(event.tojson())
+
+    def doevent(self, event):
+
+        """ 
+            dispatch an event. 
+
+            :param event: event to dispatch.
+            :rtype: None
+
+        """
+
+        if not event:
+            return
+
+        e = cpy(event)
+
+        if event.isremote:
+            rlog(10, self.name, 'remote event .. calling gn_callbacks')
+            gn_callbacks.check(self, e)
+        else:
+            callbacks.check(self, e)
+
+        if event.remotecmnd:
+            plugins.trydispatch(self, event)
