@@ -564,12 +564,12 @@ class Botcommands(Commands):
         # execute command
         if com.threaded or ievent.threaded:
             thread = start_bot_command(com.func, (bot, ievent))
-            if thread and wait:
-                thread.join()
+            #if thread and wait:
+            #    thread.join()
         else:	
             speed = ievent.speed or com.speed
             ievent.speed = speed
-            cmndrunners[10-speed].put(com.name, com.func, bot, ievent)
+            cmndrunners.put(com.name, com.func, bot, ievent)
         return True
 
 # INIT SECTION
