@@ -36,7 +36,7 @@ if config['debug']:
 
 # locks
 alchemylock = thread.allocate_lock()
-dblocked = lockdec(alchemylock)
+alchemylocked = lockdec(alchemylock)
 sessionlock = thread.allocate_lock()
 sessionlocked = lockdec(sessionlock)
 querylock = thread.allocate_lock()
@@ -46,16 +46,7 @@ createlocked = lockdec(createlock)
 
 created = []
 
-@createlocked
-def create_all(plugname='all', base=None):
-    rlog(10, 'alchemy', 'running create_all (%s)' % plugname)
-    if plugname not in created:
-        created.append(plugname)
-        if not base:
-            base = Base
-        base.metadata.create_all()
-    else:
-        rlog(10, 'alchemy', '%s tables already created' % plugname)
+
 
 def geturi(ddir=None, mainconfig=None):
 
@@ -113,8 +104,14 @@ def dbstart(ddir=None, mainconfig=None, base=None):
     else:
         rlog(10, 'alchemy', 'starting database')
 
-    # create engine
-    engine = create_engine(dburi, strategy='threadlocal', pool_recycle=900)
+    try:
+        engine = create_engine(dburi, strategy='threadlocal', pool_recycle=60, pool_size=50, max_overflow=0)
+    except:
+        engine = create_engine(dburi, strategy='threadlocal', pool_recycle=3600)
+    #try:
+    #    engine = create_engine(dburi, pool_recycle=60, pool_size=50, max_overflow=0)
+    #except:
+    #    engine = create_engine(dburi, pool_recycle=3600)
 
     # setup metadata and session
     if not base:
@@ -122,8 +119,7 @@ def dbstart(ddir=None, mainconfig=None, base=None):
     base.metadata.bind = engine
     create_all()
     rlog(10, 'alchemy', 'done')
-    Session = scoped_session(sessionmaker())
-    Session.configure(bind=engine)
+    Session = scoped_session(sessionmaker(bind=engine, autocommit=True))
     stats.up('alchemy', 'engines')
 
     return (Session, engine)
@@ -143,6 +139,33 @@ def startmaindb(ddir=None, mainconfig=None):
     Session, engine = dbstart(ddir, mainconfig)
     #pass
 
+def dblocked(func, *args, **kwargs):
+
+    @alchemylocked
+    def dofunc(*args, **kwargs):
+        try:
+            Session.begin(subtransactions=True)
+            res = func(*args, **kwargs)
+            Session.commit()
+            try: idnr = res.indx
+            except AttributeError: idnr = None
+            Session.close()
+            return idnr or res
+        except Exception, ex:
+            Session.rollback() ; Session.close()
+            raise
+    return dofunc
+
+def create_all(plugname='all', base=None):
+    rlog(10, 'alchemy', 'running create_all (%s)' % plugname)
+    if plugname not in created:
+        created.append(plugname)
+        if not base:
+            base = Base
+        try: base.metadata.create_all()
+        except Exception, ex: rlog(10, 'alchemy', 'problem creating %s tables: %s' % (str(base), str(ex)))
+    else:
+        rlog(10, 'alchemy', '%s tables already created' % plugname)
 
 ### MODEL
 
@@ -224,152 +247,11 @@ class Passwords(Base):
 
 ### END MODEL
 
-def trans(func, ismethod=True):
-
-    """ transaction function attribute. """
-
-    def dotransaction(*args, **kwargs):
-        arglist = list(args)
-        res = None
-        try:
-            stats.up('alchemy', 'transactions')
-            session = create_session()
-
-            try:
-                session.begin(subtransactions=True)
-            except sqlalchemy.exc.InvalidRequestError, ex:
-                rlog(10, 'alchemy', 'error %s: %s' % (str(arglist), str(ex)))
-                Session.remove()
-                #rollback(session)
-                session = create_session()
-                session.begin(subtransactions=True)
-
-            arglist2 = list(arglist)
-            if not ismethod:
-                arglist2.insert(0, session)
-            else:
-                arglist2.insert(1, session)
-
-            res = func(*arglist2, **kwargs)
-            session.flush()
-            session.commit()
-            return res
-
-        except sqlalchemy.orm.exc.FlushError, ex:
-            rollback(session)
-
-        except sqlalchemy.exc.InvalidRequestError, ex:
-            rlog(10, 'alchemy', 'error %s: %s' % (str(arglist), str(ex)))
-            rollback(session)
-
-        except sqlalchemy.exc.OperationalError, ex:
-            rollback(session)
-            if 'server has gone away' in str(ex):
-                rlog(10, 'alchemy', 'error %s: %s' % (str(arglist), str(ex)))
-            else:
-                raise
-        except sqlalchemy.exc.TimeoutError:
-            rlog(10, 'alchemy', 'timeout occured')
-            rollback(session)
-        except Exception ,ex:
-            rollback(session)
-            raise
-
-    #@dblocked
-    def transaction(*args, **kwargs):
-
-        """ the tranasction wrapper .. works on methods. """
-
-        try:
-            return dotransaction(*args, **kwargs)
-        except Exception, ex:
-            rlog(100, 'alchemy', 'transaction failed: %s' % str(ex))
-            rlog(100, 'alchemy', 'retrying')
-            return dotransaction(*args, **kwargs) 
-
-    return transaction
-
-def transfunc(func):
-
-    """ transaction wrapper for functions. """
-
-    return trans(func, ismethod=False)
-
-def rollback(session):
-
-    """ rollback on provided session. """
-
-    rlog(10, 'alchemy', 'rollback on %s' % str(session))
-    session.rollback()
-
-def close(session):
-
-    """ close provided session. """
-
-    #rollback(session)
-    session.close()
-    rlog(10, 'alchemy', '%s closed' % str(session))
-
-#@sessionlocked
-def create_session():
-
-    """ create a session ready for use. """
-
-    stats.up('alchemy', 'sessions')
-    session = Session()
-    return session
-
-#@querylocked
-def query(q, session=None):
-
+def query(q):
     """ do a query on the database. """
-
-    res = None
-    #if not session:
-    session = create_session()
-    try:
-        stats.up('alchemy', 'query')
-
-        #try:
-        #    session.begin(subtransactions=True)
-        #except sqlalchemy.exc.InvalidRequestError, ex:
-        #    rlog(10, 'alchemy', 'error %s: %s' % (str(q), str(ex)))
-            #Session.remove()
-        #    close(session)
-        #    session = create_session()
-        #    session.begin(subtransactions=True)
-
-        res = session.query(q)
-        return res
-
-
-    except sqlalchemy.exc.TimeoutError:
-        rlog(10, 'alchemy', 'timeout occured')
-        rollback(session)
-
-    except sqlalchemy.exc.InvalidRequestError, ex:
-        rlog(10, 'alchemy', 'error %s: %s' % (str(arglist), str(ex)))
-        rollback(session)
-
-    except sqlalchemy.exc.OperationalError, ex:
-        if 'server has gone away' in str(ex):
-            rlog(10, 'alchemy', 'error %s: %s' % (str(arglist), str(ex)))
-            rollback(session)
-        else:
-            rollback(session)
-            raise
-
-    except Exception ,ex:
-        rollback(session)
-        raise
-
-    try:
-        session = create_session()
-        res = session.query(q)
-        return res
-    except Exception, ex:
-        rollback(session)
-        raise
+    stats.up('alchemy', 'query')
+    res = Session.query(q)
+    return res
 
 def douser(userhost):
     user = query(UserHost).filter_by(userhost=userhost).first()
@@ -378,13 +260,12 @@ def douser(userhost):
         if res: 
             return res
 
-def getuser(userhost, session=None):
+
+def getuser(userhost):
 
     """ get a user based on userhost. """
 
     stats.up('alchemy', 'getuser')
-    #if not session:
-    session = create_session()
     try:
         return douser(userhost)
     except sqlalchemy.exc.OperationalError, ex:
@@ -393,47 +274,38 @@ def getuser(userhost, session=None):
             startmaindb()
             return douser(userhost)
         else:
-            rollback(session)
             raise
     except Exception, ex:
         rlog(10, 'alchemy', 'error getting %s user: %s' % (str(userhost), str(ex)))
 
-
-def doname(name, session):
-        res = query(User, session).filter_by(name=name.lower()).first()
+def doname(name):
+        res = Session.query(User).filter_by(name=name.lower()).first()
         return res
 
-def byname(name , session=None):
-
+def byname(name):
     """ get a users based on name. """
-    if not session:
-        session = create_session()
     try:
-        return doname(name, session)
-    except sqlalchemy.exc.InvalidRequestError, ex:
-        rlog(10, 'alchemy', 'error getting %s user: %s' % (str(name), str(ex)))
-        rollback(session)
-
-    except sqlalchemy.exc.OperationalError, ex:
+        return doname(name)
+    except Exception, ex:
         if 'server has gone away' in str(ex):
             rlog(10, 'alchemy', 'error: %s' % str(ex))
             startmaindb()
-            session = create_session()
-            return doname(name, session)
+            return doname(name)
         else:
             raise
 
-@transfunc
-def dbupgrade(session, mainconfig=None):
+@dblocked
+def dbupgrade(mainconfig=None):
 
     """ upgrade the database. """
 
     #time.sleep(10)
     print 'upgrading users'
-    users = session.query(UserHost).all()
+    users = Session.query(UserHost).all()
     upgraded = []
 
     # populate the User table
+    Session.begin()
     for user in users:
         name = user.name
         if name in upgraded:
@@ -448,7 +320,8 @@ def dbupgrade(session, mainconfig=None):
         except:
             handle_exception()
 
-    session.commit()
+    Session.commit()
+    Session.close()
     print "upgraded: %s" % ' .. '.join(upgraded) 
     print 'upgrading email table'
     from gozerbot.database.db import Db
