@@ -34,6 +34,8 @@ def makedirs(ddir=None):
 
     if not os.path.isdir(ddir):
         os.mkdir(ddir)
+    if not os.path.isdir(ddir + '/run/'):
+        os.mkdir(ddir + '/run/')
     if not os.path.isdir(ddir + '/users/'):
         os.mkdir(ddir + '/users/')
     if not os.path.isdir(ddir + '/db/'):
