@@ -18,7 +18,6 @@ __copyright__ = 'this file is in the public domain'
 import os, sys
 from utils.exception import handle_exception
 from utils.log import rlog
-from gozerbot.config import config
 
 # END IMPORT
 
@@ -182,9 +181,8 @@ def loadeggs(eggdir, log=True):
 # INIT SECTION
 
 
-if not config['PAE']:
-    # first search for setuptools and load it
-    init(os.getcwd())
-    init(os.getcwd() + os.sep + 'gozernest')
+# first search for setuptools and load it
+init(os.getcwd())
+init(os.getcwd() + os.sep + 'gozernest')
 
 # END INIT
