@@ -2,29 +2,56 @@
 #
 #
 
-""" event handlers """
+"""
+    event handler. use to dispatch function in main loop.
+
+"""
 
 __copyright__ = 'this file is in the public domain'
 
-from gozerbot.generic import handle_exception, rlog, lockdec
-from gozerbot.thr import start_new_thread
+# ==============
+# IMPORT SECTION
+
+# gozerbot imports
+from utils.exception import handle_exception
+from utils.log import rlog
+from utils.locking import lockdec
+from threads.thr import start_new_thread
+
+# basic imports
 import Queue, thread
 
+# END IMPORT
+# ==========
+
+# ============
+# LOCK SECTION
+
+# locks
 handlerlock = thread.allocate_lock()
 locked = lockdec(handlerlock)
 
+# END LOCK
+# ========
+
+## START
+
 class Eventhandler(object):
 
-    """ events are handled in 11 queues with different priorities:
-        queue0 is tried first queue10 last
+    """
+        events are handled in 11 queues with different priorities:
+        queue0 is tried first queue10 last.
+
     """
 
     def __init__(self):
         self.sortedlist = []
         self.queues = {}
+
         for i in range(11):
             self.queues[i] = Queue.Queue()
             self.sortedlist.append(i)
+
         self.sortedlist.sort()
         self.go = Queue.Queue()
         self.stopped = False
@@ -32,51 +59,116 @@ class Eventhandler(object):
         self.nooutput = False
 
     def start(self):
-        """ start the eventhandler thread """
+
+        """
+            start the eventhandler thread.
+
+            .. literalinclude:: ../../gozerbot/eventhandler.py
+                   :pyobject: Eventhandler.start
+
+        """
+
         self.stopped = False
+
         if not self.running:
             start_new_thread(self.handleloop, ())
             self.running = True
 
     def stop(self):
-        """ stop the eventhandler thread """
+
+        """
+            stop the eventhandler thread.
+
+            .. literalinclude:: ../../gozerbot/eventhandler.py
+                :pyobject: Eventhandler.stop
+
+        """
+
         self.running = False
         self.stopped = True
         self.go.put('Yihaaa')
 
     def put(self, speed, func, *args, **kwargs):
-        """ put item on the queue """
+
+        """
+             put item on the queue.
+
+             .. literalinclude:: ../../gozerbot/eventhandler.py
+                 :pyobject: Eventhandler.put
+
+        """
+
         self.queues[10-speed].put_nowait((func, args, kwargs))
         self.go.put('go')
 
     def getready(self):
-        """ check queues from available data """
+
+        """
+            check queues from available functions to execute.
+
+            .. literalinclude:: ../../gozerbot/eventhandler.py
+                :pyobject: Eventhandler.getready
+
+        """
+
         ready = []
+
         for i in self.sortedlist:
             if self.queues[i].qsize():
                 ready.append(i)
+                break
+
         return ready
 
     def handle_one(self):
-        """ do 1 loop over ready queues """
+
+        """
+            do 1 loop over ready queues.
+
+            .. literalinclude:: ../../gozerbot/eventhandler.py
+                :pyobject: Eventhandler.handle_one
+
+        """
+
         ready = self.getready()
+
         for i in ready:
             self.dispatch(self.queues[i])
 
     def handleloop(self):
-        """ thread that polls the queues for items to dispatch """
+
+        """
+            thread that polls the queues for items to dispatch.
+
+            .. literalinclude:: ../../gozerbot/eventhandler.py
+                :pyobject: Eventhandler.handleloop
+
+        """
+
         rlog(0, 'eventhandler', 'starting handle thread')
+
         while not self.stopped:
             self.go.get()
             self.handle_one()
+
         rlog(0, 'eventhandler', 'stopping %s' % str(self))
 
     def dispatch(self, queue):
-        """ dispatch functions from provided queue """
+
+        """
+            dispatch functions from provided queue.
+
+            .. literalinclude:: ../../gozerbot/eventhandler.py
+                :pyobject: Eventhandler.dispatch
+
+        """
+
+
         try:
             todo = queue.get_nowait()
         except Queue.Empty:
             return
+
         try:
             (func, args, kwargs) = todo
             func(*args, **kwargs)
@@ -87,80 +179,14 @@ class Eventhandler(object):
             except ValueError:
                 (func, ) = todo
                 func()
+
         except:
             handle_exception()
 
-class Irchandler(Eventhandler):
-
-    """ handles ircevents """
-
-    def put(self, speed, bot, ievent):
-        """ put item on the queue """
-        self.queues[10-speed].put_nowait((bot, ievent))
-        self.go.put('go')
-
-    def dispatch(self, queue):
-        """ dispatch ircevents from provided queue """
-        try:
-            (bot, ievent) = queue.get_nowait()
-            bot.handle_ievent(ievent)
-        except Queue.Empty:
-            return
-        except:
-            handle_exception()
-
-class Commandhandler(Eventhandler):
-
-    """ handle bot commands """
-
-    def put(self, speed, what, com, bot, ievent):
-        """ put item on the queue """
-        self.queues[10-speed].put_nowait((what, com, bot, ievent))
-        self.go.put('go')
-
-    def dispatch(self, queue):
-        """ dispatch bot commands from provided queue """
-        try:
-            (what, com, bot, ievent) = queue.get_nowait()
-            rlog(10, 'eventhandler', '%s (%s) executing %s' % (ievent.nick, \
-ievent.userhost, ievent.txt))
-            what.dispatch(com, bot, ievent)
-        except Queue.Empty:
-            return
-        except:
-            handle_exception()
-
-class Outputhandler(Eventhandler):
-
-    """ handle bot output """
-
-    def __init__(self, bot):
-        Eventhandler.__init__(self)
-        self.bot = bot
-        self.lastout = 0
-        
-    def handle_one(self):
-        """ do 1 loop over ready queues """
-        if self.nooutput:
-            self.go.put('later')
-            return
-        if self.bot.outputlock.locked():
-            self.go.put('later')
-            return
-        ready = self.getready()
-        for i in ready:
-            self.dispatch(self.queues[i])
-
-    def dispatch(self, queue):
-        """ dispatch bot commands from provided queue """
-        try:
-            (bot, printto, what, how, who, fromm) = queue.get_nowait()
-            bot.output(printto, what, how, who, fromm)
-        except Queue.Empty:
-            return
-        except:
-            handle_exception()
+# INIT SECTION
 
 # handler to use in main prog
 mainhandler = Eventhandler()
-commandhandler = Commandhandler()
+
+
+# END INIT
\ No newline at end of file
