@@ -18,9 +18,10 @@ from plugins import plugins
 from fleet import fleet
 from persist.persist import saving
 from runner import runners_stop
+from gozerbot.config import config
 
 # basic imports
-import atexit, os, time
+import atexit, os, time, sys
 
 # END IMPORT
 # ==========
@@ -58,6 +59,7 @@ def globalshutdown():
         plugins.exit()
         rlog(10, 'GOZERBOT', 'done')
         os._exit(0)
+
     except Exception, ex:
         rlog(10, 'gozerbot.exit', 'exit error %s:' % str(ex))
 
@@ -65,7 +67,7 @@ def globalshutdown():
 # INIT SECTION
 
 # register shutdown function
-atexit.register(globalshutdown)
+#atexit.register(globalshutdown)
 
 # END INIT
 # ========
