@@ -32,6 +32,7 @@ from ircevent import Ircevent
 
 # basic imports
 import re, socket, struct, Queue, time, os, types
+from errno import EAGAIN
 
 # RE to determine if a DCC chat request is received
 dccchatre = re.compile('\001DCC CHAT CHAT (\S+) (\d+)\001', re.I)
@@ -140,13 +141,13 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
                 # skip on timeout 
                 continue
             except socket.error, ex:
-                # handle socket errors .. skip on errno 35 and 11 temp unavail
+                # handle socket errors .. skip on errno EAGAIN temp unavail
                 try:
                     (errno, errstr) = ex
                 except:
                     errno = 0
                     errstr = str(ex)
-                if errno == 35 or errno == 11:
+                if errno == EAGAIN:
                     continue
                 else:
                     raise
@@ -211,7 +212,7 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
                 except:
                     errno = 0
                     errstr = str(ex)
-                if errno == 35 or errno == 11:
+                if errno == EAGAIN:
                     continue
             except Exception, ex:
                 handle_exception()
