@@ -30,6 +30,7 @@ from ircevent import Ircevent
 
 # basic imports
 import time, thread, socket, threading, os, Queue, random
+from errno import EAGAIN, EBADF, EPIPE
 
 # locks
 outlock = thread.allocate_lock()
@@ -109,7 +110,7 @@ class Irc(BotBase):
             # used for nonblocking sockets
             try:
                 (errno, errstr) = ex
-                if errno != 32 and errno != 9:
+                if errno != EPIPE and errno != EBADF:
                     raise
                 else:
                     time.sleep(0.5)
@@ -204,9 +205,14 @@ class Irc(BotBase):
         # enable ssl if set
         if self.cfg.has_key('ssl') and self.cfg['ssl']:
             rlog(10, self.name, 'ssl enabled')
-            self.sock = socket.ssl(self.oldsock) 
-        else:
-            self.sock = self.oldsock
+            try:
+                import ssl
+                rlog(10, self.name, 'using ssl.wrap_socket()')
+                self.sock = ssl.wrap_socket(self.oldsock)
+            except Exception, ex:
+                rlog(10, self.name, 'using socket.ssl()')
+                self.sock = socket.ssl(self.oldsock)
+        else: self.sock = self.oldsock
 
         # try to release the outputlock
         try:
@@ -323,7 +329,7 @@ class Irc(BotBase):
                     time.sleep(0.5)
                     continue
                 handle_exception()
-                reconnect = 1
+                doreconnect = 1
                 break
 
             except Exception, ex:
@@ -336,8 +342,8 @@ class Irc(BotBase):
                     errno = -1
                     msg = err
                 # check for temp. unavailable error .. raised when using
-                # nonblocking socket .. 35 is FreeBSD 11 is Linux
-                if errno == 35 or errno == 11:
+                # nonblocking socket ..
+                if errno == EAGAIN:
                     time.sleep(0.5)
                     continue
                 rlog(10, self.name, "error in readloop: %s" % msg)
@@ -896,14 +902,14 @@ reconsleep)
 
         try:
             self.outputlock.acquire()
+            txt = toenc(strippedtxt(txt))
+            txt = txt.rstrip()
+            self._raw(txt)
             now = time.time()
             timetosleep = 5 - (now - self.lastoutput)
             if timetosleep > 0 and not self.nolimiter:
                 rlog(0, self.name, 'flood protect')
                 time.sleep(timetosleep)
-            txt = toenc(strippedtxt(txt))
-            txt = txt.rstrip()
-            self._raw(txt)
             try:
                 self.outputlock.release()
             except:
@@ -1124,6 +1130,9 @@ ievent.txt))
         except:
             pass
 
+    handle_403 = handle_401
+
+
     def handle_700(self, ievent):
 
         """ handle 700 .. encoding request of the server. """
