@@ -28,7 +28,7 @@ class Outmonitor(Monitor):
         ievent.nick = bot.nick
 
         try:
-            ievent.userhost = bot.userhosts[bot.nick]
+            ievent.userhost = bot.userhosts.data[bot.nick]
         except KeyError:
             ievent.userhost = "bot@bot"
 
