@@ -22,7 +22,7 @@ from utils.exception import handle_exception
 from utils.trace import calledfrom
 from config import config
 from threads.threadloop import ThreadLoop
-from runner import cbrunners
+from runner import waitrunners
 import threads.thr as thr
 
 # basic imports
@@ -139,7 +139,7 @@ class Monitor(ThreadLoop):
             try:
                 if i[2]:
                     stats.up('monitors', thr.getname(str(i[2])))
-                    rlog(-10, 'jabbermonitor', 'checking inloop %s' % str(i[2]))
+                    rlog(-10, 'monitor', 'checking inloop %s' % str(i[2]))
                     doit = i[2](*args, **kwargs)
                 else:
                     doit = 1
@@ -150,12 +150,10 @@ class Monitor(ThreadLoop):
 
             if doit:
                 # run monitor callback in its own thread
-                rlog(0, 'jabbermonitor', 'excecuting jabbermonitor callback \
-%s' % i[0])
+                rlog(0, 'monitor', 'excecuting monitor callback %s' % i[0])
                 stats.up('monitors', thr.getname(str(i[1])))
-
                 if not i[3]:
-                    cbrunners[5].put("monitor-%s" % i[0], i[1], *args)
+                    waitrunners.put("monitor-%s" % i[0], i[1], *args)
                 else:
                     thr.start_new_thread(i[1], args, kwargs)
 
