@@ -274,6 +274,12 @@ class Periodical(object):
                 i.interval = interval
                 i.next = time.time() + interval
 
+    def looponce(self):
+        for job in self.jobs:
+
+            if job.next <= time.time():
+                self.runjob(job)
+
     def checkloop(self):
 
         """
