@@ -139,8 +139,7 @@ class PlugPersist(Persist):
         plugname = calledfrom(sys._getframe())
 
         # call base constructor with appropiate filename
-        Persist.__init__(self, datadir + os.sep + 'plugs' + os.sep + plugname \
-+ os.sep + filename, default)
+        Persist.__init__(self, datadir + os.sep + 'plugs' + os.sep + plugname + os.sep + filename, default)
 
 
 class LazyDictPersist(Persist):
