@@ -6,9 +6,8 @@
 
 __copyright__ = 'this file is in the public domain'
 
-## IMPORT SECTION
+## gozerbot imports
 
-# gozerbot imports
 from gozerbot.stats import stats
 from gozerbot.tests import tests
 from gozerbot.datadir import datadir
@@ -290,18 +289,16 @@ class Plugins(object):
             return
 
         if name in self.plugdeny.data:
-            rlog(0, 'plugins', '%s.%s in deny .. not loading' % \
-(mod, name))
+            rlog(0, 'plugins', '%s.%s in deny .. not loading' % (mod, name))
             return 0
 
-        if config.has_key('loadlist') and name not in config['loadlist'] and 'gozerplugs' in modname and name not in self.plugallow.data:
+        if config.has_key('loadlist') and name not in config['loadlist'] and 'gplugs' in modname and name not in self.plugallow.data:
                 rlog(9, 'plugins', 'not loading %s.%s' % (mod, name))
                 return 0
 
         # if plugin is already registered unload it
         if self.plugs.has_key(name):
-            rlog(10, 'plugins', 'overloading %s plugin with %s version' \
-% (name, mod))
+            rlog(10, 'plugins', 'overloading %s plugin with %s version' % (name, mod))
             self.unloadnosave(name)
 
         # create the plugin data dir
@@ -437,11 +434,11 @@ class Plugins(object):
         else:
             rlog(10, 'plugins', 'no myplugs directory found')
 
-        # check for gozerplugs package
+        # check for gplugs package
         try:
-            gplugs = gozer_import('gozerplugs')
+            gplugs = gozer_import('gplugs')
         except ImportError:
-            rlog(20, 'plugins', "no gozerplugs package found")
+            rlog(20, 'plugins', "no gplugs package found")
             gplugs = None
 
         if gplugs:
@@ -449,11 +446,46 @@ class Plugins(object):
             for i in gplugs.__plugs__:
 
                 try:
-                    self.regplugin('gozerplugs', i)
+                    self.regplugin('gplugs', i)
                     avail.append(i)
                 except Exception, ex:
                     handle_exception()
 
+        if config.get('db_driver') == "olddb":
+            # check for gplugs package
+            try:
+                gplugs = gozer_import('gplugs.olddb')
+            except ImportError:
+                rlog(20, 'plugins', "no gplugs.old package found")
+                gplugs = None
+
+            if gplugs:
+
+                for i in gplugs.__plugs__:
+
+                    try:
+                        self.regplugin('gplugs.olddb', i)
+                        avail.append(i)
+                    except Exception, ex:
+                        handle_exception()
+        else:
+            # check for gplugs package
+            try:
+                gplugs = gozer_import('gplugs.alchemy')
+            except ImportError:
+                rlog(20, 'plugins', "no gplugs.alchemy package found")
+                gplugs = None
+
+            if gplugs:
+
+                for i in gplugs.__plugs__:
+
+                    try:
+                        self.regplugin('gplugs.alchemy', i)
+                        avail.append(i)
+                    except Exception, ex:
+                        handle_exception()
+
         self.ondisk.extend(avail)
         self.readoverload()
         start_new_thread(self.showregistered, ())
@@ -693,7 +725,7 @@ perms))
         if plugname in self.plugs:
             plug = self.plugs[plugname]
         else:
-            for mod in ['gozerbot.plugs', 'gozerplugs', 'myplugs']:
+            for mod in ['gozerbot.plugs', 'gplugs', 'myplugs']:
                 try:
                     plug = gozer_import('%s.%s' % (mod, plugname))
                 except ImportError:
@@ -1407,9 +1439,16 @@ perms))
                 except ImportError, ex:
 
                     try:
-                        self.reload('gozerplugs', plugin)
+                        self.reload('gplugs', plugin)
                     except ImportError, ex:
-
+                        if config.get('db_driver') == 'olddb':
+                            try:
+                                self.reload('gplugs.olddb', plugin)
+                            except ImportError, ex: pass
+                        else:
+                            try:
+                                self.reload('gplugs.alchemy', plugin)
+                            except ImportError, ex: pass
                         try:
                             self.reload('myplugs', plugin)
                         except ImportError, ex:
@@ -1443,7 +1482,12 @@ perms))
             mod = '.'.join(splitted[:-1])
 
             if not mod:
-                mod = 'gozerplugs'
+                if config.get('db_driver') == "olddb":
+                    mod = "gplugs.olddb"
+                elif config.get("db_driver") == "alchemy":
+                    mod = "gplugs.alchemy"
+                else:
+                    mod = 'gplugs'
 
             plug  = splitted[-1]
 
