@@ -10,11 +10,13 @@ from gozerbot.aliases import aliasreverse
 from gozerbot.examples import examples
 from gozerbot.plughelp import plughelp
 
+import os
+
 plughelp.add("admin", "admin related functions.")
 
 def handle_cmndtablesave(bot, ievent):
-
-    cmndtable = Persist('cmndtable')
+    from gozerbot.datadir import datadir
+    cmndtable = Persist(datadir + os.sep + 'run' + os.sep + 'cmndtable')
     if not cmndtable.data:
         cmndtable.data = {}
 
@@ -32,7 +34,8 @@ examples.add("admin-cmndtable", "save the command table", "admin-cmndtable")
 
 def handle_pluginlist(bot, ievent):
     plugins = []
-    pluginlist = Persist('pluginlist')
+    from gozerbot.datadir import datadir
+    pluginlist = Persist(datadir + os.sep + 'run' + os.sep + 'pluginlist')
     if not pluginlist.data:
         pluginlist.data = []
     for cmndname, c in cmnds.iteritems():
