@@ -555,16 +555,14 @@ def handle_running(bot, ievent):
     stats = [Statdict() for i in range(10)]
     teller = 0
 
-    for runners in cbrunners:
-        for runner in runners.running():
-            stats[teller].upitem(runner)
+    for runner in cbrunners.running():
+        stats[teller].upitem(runner)
         teller += 1
 
     teller = 0
 
-    for runners in cmndrunners:
-        for runner in runners.running():
-            stats[teller].upitem(runner)
+    for runner in cmndrunners.running():
+        stats[teller].upitem(runner)
         teller += 1
 
     result = []
@@ -583,16 +581,14 @@ tests.add('running')
 def handle_nowrunning(bot, ievent):
     result = []
 
-    for runners in cbrunners:
-        for runner in runners.runners:
-            result.append(runner.nowrunning)
+    for runner in cbrunners.runners:
+        result.append(runner.nowrunning)
 
     ievent.reply('nowrunning callbacks: %s' % str(result))
     result = []
 
-    for runners in cmndrunners:
-        for runner in runners.runners:
-            result.append(runner.nowrunning)
+    for runner in cmndrunners.runners:
+        result.append(runner.nowrunning)
 
     ievent.reply('nowrunning commands: %s' % str(result))
 
