@@ -19,6 +19,8 @@ def handle_plugenable(bot, ievent):
 
     doall = False
     plugs = []
+    oldplugs = []
+    alchemyplugs = []
 
     if '-a' in ievent.optionset:
         doall = True
@@ -28,8 +30,19 @@ def handle_plugenable(bot, ievent):
         return
 
     if doall:
+        if config.get('db_driver') == "olddb":
+            try:
+                oldplugs = gozer_import('gplugs.olddb').__plugs__
+            except ImportError:
+                pass
+        else:
+            try:
+                alchemyplugs = gozer_import('gplugs.alchemy').__plugs__
+            except ImportError:
+                pass
+
         try:
-            plugs = gozer_import('gozerplugs').__plugs__
+            plugs.extend(gozer_import('gplugs').__plugs__)
         except ImportError:
             pass
 
@@ -46,19 +59,32 @@ def handle_plugenable(bot, ievent):
     reloaded = []
     failed = []
 
-    for plug in plugs:
-        try:
-            reloaded.extend(plugins.reload('gozerplugs', plug))
-        except ImportError, ex:
+    if config.get('db_driver') == "olddb":
+        for plug in oldplugs:
             try:
-                reloaded.extend(plugins.reload('myplugs', plug))
+                reloaded.extend(plugins.reload('gplugs.olddb', plug))
+            except ImportError, ex: pass
+    else:
+        for plug in alchemyplugs:
+            try:
+                reloaded.extend(plugins.reload('gplugs.alchemy', plug))
+            except ImportError, ex: pass
+
+    if True:
+        for plug in plugs: 
+            try:
+                reloaded.extend(plugins.reload('gplugs', plug))
             except ImportError, ex:
-                errors.append(str(ex))
+                try:
+                    reloaded.extend(plugins.reload('myplugs', plug))
+                except ImportError, ex: pass
+                except Exception, ex:
+                    failed.append(plug)
+                    errors.append(str(ex))
+            except Exception, ex:
+                handle_exception()
+                errors.append(exceptionmsg())
                 failed.append(plug)
-        except Exception, ex:
-            handle_exception()
-            errors.append(exceptionmsg())
-            failed.append(plug)
 
     ievent.reply('enabled plugins: ', reloaded, dot=True)
   
@@ -95,64 +121,3 @@ def handle_plugdisable(bot, ievent):
 cmnds.add('plug-disable', handle_plugdisable, 'OPER')
 examples.add('plug-disable', 'disable a plugin', 'plug-disable karma')
 tests.add('plug-disable country', 'country')
-
-def handle_plugupgrade(bot, ievent):
-
-    """ upgrade a plugin(s). """
-
-    alreadygot = []
-    upgraded = []
-    plugs = []
-
-    try:
-        plugs = gozer_import('gozerplugs').__plugs__
-    except ImportError:
-        ievent.reply("no gozerplugs package detected")
-        return
-
-    if ievent.rest:
-        plugs.extend(ievent.rest.split())
-    else:
-        for name, plug in plugins.plugs.iteritems():
-            if hasattr(plug, 'upgrade'):
-                plugs.append(name)    
-
-    ievent.reply('starting plugin upgrade for plugins: ', plugs, dot=True)
-    errors = []
-
-    for plug in plugs:
-        if not plugins.plugs.has_key(plug):
-            plugins.reload('gozerplugs', plug, enable=False)
-        
-        try:
-            s = plugins.plugs[plug].size()
-        except AttributeError:
-            s = 0
-
-        if s and not '-f' in ievent.optionset:
-            alreadygot.append(plug)
-            continue
-
-        try:
-            plugins.plugs[plug].upgrade()
-            plugins.reload('gozerplugs', plug)
-            ievent.reply('upgraded %s' % plug)
-            upgraded.append(plug)
-        except AttributeError:
-            continue
-        except Exception, ex:
-            handle_exception()
-            errors.append(exceptionmsg())
-
-    if upgraded:
-        ievent.reply('upgraded the following plugins: ', upgraded, dot=True)
-
-    if alreadygot:
-        ievent.reply("%s plugins already have data .. use -f to force upgrade" % ' .. '.join(alreadygot))
-
-    if errors:
-        ievent.reply("errors: ", errors, dot=True)
-
-cmnds.add('plug-upgrade', handle_plugupgrade, 'OPER', options={'-f': ''}, threaded=True)
-examples.add('plug-upgrade', 'plug-upgrade {<list of plugs>] .. upgrade all plugins or a specified plugin', 'plug-upgrade url')
-tests.add('plug-upgrade url', 'url')
