@@ -50,9 +50,19 @@ def handle_reload(bot, ievent):
             reloaded.extend(plugins.reload('myplugs', plug))
         except ImportError, ex:
             try:
-                reloaded.extend(plugins.reload('gozerplugs', plug))
+                reloaded.extend(plugins.reload('gplugs', plug))
             except ImportError, ex:
                 errors.append(str(ex))
+                if config.get('db_driver') == "olddb":
+                    try:
+                        reloaded.extend(plugins.reload('gplugs.olddb', plug))
+                    except ImportError, ex:
+                        errors.append(str(ex))
+                else:
+                    try:
+                        reloaded.extend(plugins.reload('gplugs.alchemy', plug))
+                    except ImportError, ex:
+                        errors.append(str(ex))
 
     ievent.reply('reloaded: ', reloaded, dot=True)
 
