@@ -282,7 +282,7 @@ def handle_addperm(bot, ievent):
         ievent.reply('%s already has permission %s' % (name, perm))
         return         
 
-    result = users.adduserperm(name, perm)
+    result = users.addperm(name, perm)
 
     if result:
         ievent.reply('%s perm added' % perm)
@@ -391,7 +391,7 @@ def handle_addstatus(bot, ievent):
         ievent.reply('%s already has status %s' % (name, status))
         return
 
-    result = users.adduserstatus(name, status)
+    result = users.addstatus(name, status)
 
     if result:
         ievent.reply('%s status added' % status)
@@ -684,7 +684,7 @@ def handle_addpermit(bot, ievent):
         ievent.reply('%s is already allowed to do %s' % (who, what))
         return
 
-    result = users.adduserpermit(name, who, what)
+    result = users.addpermit(name, who, what)
 
     if result:
         ievent.reply('permit added')
