@@ -72,7 +72,7 @@ threaded=True, allowqueue=True, options={}):
         self.threaded = copy.deepcopy(threaded) # set when run threaade
         self.allowqueue = copy.deepcopy(allowqueue) # set when pipeline is allowed
         self.options = dict(options) # options set on the callback
-        self.activate = False
+        self.activate = True
 
 class REDispatcher(object):
 
@@ -370,7 +370,7 @@ class BotREDispatcher(REDispatcher):
                 if callback.threaded or ievent.threaded:
                     thread = thr.start_bot_command(callback.func, (bot, ievent))
 
-                    if wait:
+                    if thread and wait:
                         thread.join()
 
                 else:
