@@ -9,6 +9,7 @@ __copyright__ = 'this file is in the public domain'
 # gozerbot imports
 from gozerbot.utils.log import rlog
 from gozerbot.config import config
+from gozerbot.utils.exception import handle_exception
 
 # core thread import
 from thr import start_new_thread
@@ -29,26 +30,26 @@ class ThreadLoop(object):
         self.nowrunning = "none"
 
     def _loop(self):
-        rlog(0, self.name, 'starting threadloop')
-        self.running = True
-
+        rlog(0, "threadloop", 'starting threadloop')
         while not self.stopped:
-
             try:
-                data = self.queue.get_nowait()
-            except Queue.Empty:
+                self.running = True
+                try:
+                    data = self.queue.get_nowait()
+                except Queue.Empty:
+                    if self.stopped:
+                        break
+                    time.sleep(0.1)
+                    continue
+
                 if self.stopped:
                     break
-                time.sleep(0.1)
-                continue
 
-            if self.stopped:
-                break
-
-            if not data:
-                break
-            rlog(-1, self.name, 'running %s' % str(data))
-            self.handle(*data)
+                if not data:
+                    break
+                rlog(0, self.name, 'running %s' % str(data))
+                self.handle(*data)
+            except Exception, ex: handle_exception()
 
         self.running = False
         rlog(0, self.name, 'stopping threadloop')
@@ -86,7 +87,7 @@ class RunnerLoop(ThreadLoop):
 
 
     def _loop(self):
-        rlog(0, self.name, 'starting threadloop')
+        rlog(0, "runnerloop", 'starting threadloop')
         self.running = True
 
         while not self.stopped:
@@ -106,11 +107,11 @@ class RunnerLoop(ThreadLoop):
                 break
 
             self.nowrunning = data[0]
-            rlog(0, self.name, 'now running %s' % self.nowrunning)
+            rlog(0, 'runnerloop', 'now running %s' % self.nowrunning)
             self.handle(*data)
 
         self.running = False
-        rlog(0, self.name, 'stopping threadloop')
+        rlog(0, 'runnerloop', 'stopping threadloop')
 
 class ThreadSleeper(ThreadLoop):
 
@@ -119,7 +120,7 @@ class ThreadSleeper(ThreadLoop):
         self.timeout = timeout
 
     def _loop(self):
-        rlog(0, self.name, 'starting threadloop')
+        rlog(0, 'threadsleeper', 'starting threadloop')
         self.running = True
 
         while not self.stopped:
@@ -131,4 +132,4 @@ class ThreadSleeper(ThreadLoop):
             self.handle()
 
         self.running = False
-        rlog(0, self.name, 'stopping threadloop')
+        rlog(0, 'threadsleeper', 'stopping threadloop')
