@@ -68,18 +68,26 @@ def makedirs(datadir):
 def cleanpyc():
     removed = []
     try:
-        files = os.listdir('gozerplugs')
+        files = os.listdir('gplugs')
         for file in files:
             if file.endswith('.pyc'):
-                os.unlink('gozerplugs' + os.sep + file)
+                os.unlink('gplugs' + os.sep + file)
                 removed.append(file)
     except:
         pass
     try:
-        files = os.listdir('gozerplugs/plugs')
+        files = os.listdir('gplugs/olddb')
         for file in files:
             if file.endswith('.pyc'):
-                os.unlink('gozerplugs/plugs' + os.sep + file)
+                os.unlink('gplugs/olddb' + os.sep + file)
+                removed.append(file)
+    except:
+        pass
+    try:
+        files = os.listdir('gplugs/alchemy')
+        for file in files:
+            if file.endswith('.pyc'):
+                os.unlink('gplugs/alchemy' + os.sep + file)
                 removed.append(file)
     except:
         pass
@@ -98,7 +106,9 @@ def getversion():
     if config['nodb']:
         version += ' JSON_USERS'
     else:
-        version += ' ' + config['dbtype'].upper()
+        driver = config.get("db_driver")
+        if driver: driver = driver.upper()
+        version += ' ' + config['dbtype'].upper() + ' ' + driver or ""
     return version
 
 def makeoptions(ievent, options={}):
