@@ -7,7 +7,7 @@
 __copyright__ = 'this file is in the public domain'
 
 from log import rlog
-import thread
+import thread, threading
 
 class Lockmanager(object):
 
@@ -18,13 +18,11 @@ class Lockmanager(object):
 
     def allocate(self, name):
         """ allocate a new lock """
-        name = name.lower()
         self.locks[name] = thread.allocate_lock()
-        rlog(10, 'lockmanager', 'allocated %s' % name)
+        rlog(0, 'lockmanager', 'allocated %s' % name)
         
     def get(self, name):
         """ get lock """
-        name = name.lower()
         if not self.locks.has_key(name):
             self.allocate(name)
         return self.locks[name]
@@ -36,16 +34,23 @@ class Lockmanager(object):
 
     def acquire(self, name):
         """ acquire lock """
-        name = name.lower()
         if not self.locks.has_key(name):
             self.allocate(name)
-        rlog(10, 'lockmanager', 'acquire %s' % name)
+        rlog(0, 'lockmanager', 'acquire %s' % name)
         self.locks[name].acquire()
 
     def release(self, name):
         """ release lock """
-        name = name.lower()
-        rlog(10, 'lockmanager', 'releasing %s' % name)
+        rlog(0, 'lockmanager', 'releasing %s' % name)
         self.locks[name].release()
 
+
+class RLockManager(Lockmanager):
+
+    def allocate(self, name):
+        """ allocate a new lock """
+        self.locks[name] = threading.RLock()
+        rlog(0, 'lockmanager', 'allocated RLock %s' % name)
+
 lockmanager = Lockmanager()
+rlockmanager = RLockManager()
