@@ -4,13 +4,21 @@
 
 """ name related helper functions. """
 
-import string
+## basic imports
 
-allowednamechars = string.ascii_letters + string.digits
+import string
+import os
+
+## defines
+
+allowednamechars = string.ascii_letters + string.digits + '!.@-'
+
+## functions
 
 def stripname(txt):
     res = ""
     for c in txt:
         if c in allowednamechars:
             res += c
+    res.replace(os.sep, '-')
     return res
