@@ -176,7 +176,8 @@ environ = {'REQUEST_METHOD':'POST'}, keep_blank_values = 1)
 def decode_html_entities(s):
     """ smart decoding of html entities to utf-8 """
     re_ent_match = re.compile(u'&([^;]+);')
-    re_entn_match = re.compile(u'&#([^;]+);')
+    re_entn_match = re.compile(u'&#([^x;]+);')
+    re_entnx_match = re.compile(u'&#x([^;]+);')
     s = s.decode('utf-8', 'replace')
     def to_entn(match):
         """ convert to entities """
@@ -187,8 +188,12 @@ def decode_html_entities(s):
     def to_utf8(match):
         """ convert to utf-8 """
         return unichr(long(match.group(1)))
+    def to_utf8x(match):
+        """ convert to utf-8 """
+        return unichr(long(match.group(1), 16))
     s = re_ent_match.sub(to_entn, s)
     s = re_entn_match.sub(to_utf8, s)
+    s = re_entnx_match.sub(to_utf8x, s)
     return s
 
 def get_encoding(data):
