@@ -6,10 +6,15 @@
 
 __copyright__ = 'this file is in the public domain'
 
-from gozerbot.generic import rlog, lockdec
-import gozerbot.thr as thr
+# gozerbot imports
+from utils.log import rlog
+from utils.locking import lockdec
+import threads.thr as thr
+
+# basic imports
 import time, thread
 
+# locks
 waitlock = thread.allocate_lock()
 locked = lockdec(waitlock)
 
@@ -22,7 +27,9 @@ class Wait(object):
         self.ticket = 0
 
     def register(self, cmnd, catch, queue, timeout=15):
-        """ register wait for cmnd """
+
+        """ register wait for cmnd. """
+
         rlog(1, 'wait', 'registering for cmnd ' + cmnd)
         self.ticket += 1
         self.waitlist.insert(0, (cmnd, catch, queue, self.ticket))
@@ -32,13 +39,15 @@ class Wait(object):
         return self.ticket
 
     def check(self, ievent):
+
         """ check if there are wait items for ievent .. check if 'catch' 
-            matches on ievent.postfix if so put ievent on queue """
+            matches on ievent.postfix if so put ievent on queue. """
+
         cmnd = ievent.cmnd
         for item in self.waitlist:
             if item[0] == cmnd:
                 if cmnd == "JOIN":
-	                    catch = ievent.txt + ievent.postfix
+	            catch = ievent.txt + ievent.postfix
                 else:
                     catch = ievent.nick + ievent.postfix
                 if item[1] in catch:
@@ -46,16 +55,21 @@ class Wait(object):
                     item[2].put_nowait(ievent)
                     self.delete(ievent.ticket)
                     rlog(1, 'wait', 'got response for %s' % item[0])
+                    ievent.isresponse = True
 
     def dotimeout(self, timeout, ticket):
-        """ start timeout thread for wait with ticket nr """
+
+        """ start timeout thread for wait with ticket nr. """
+
         rlog(1, 'wait', 'starting timeouthread for %s' % str(ticket))
         time.sleep(float(timeout))
         self.delete(ticket)
 
     @locked
     def delete(self, ticket):
-        """ delete wait item with ticket nr """
+
+        """ delete wait item with ticket nr. """
+
         for itemnr in range(len(self.waitlist)-1, -1, -1):
             if self.waitlist[itemnr][3] == ticket:
                 self.waitlist[itemnr][2].put_nowait(None)
@@ -68,12 +82,16 @@ class Privwait(Wait):
     """ wait for privmsg .. catch is on nick """
 
     def register(self, catch, queue, timeout=15):
-        """ register wait for privmsg """
+
+        """ register wait for privmsg. """
+
         rlog(1, 'privwait', 'registering for ' + catch)
         return Wait.register(self, 'PRIVMSG', catch, queue, timeout)
 
     def check(self, ievent):
-        """ check if there are wait items for ievent """
+
+        """ check if there are wait items for ievent. """
+
         for item in self.waitlist:
             if item[0] == 'PRIVMSG':
                 if ievent.userhost == item[1]:
@@ -81,13 +99,16 @@ class Privwait(Wait):
                     item[2].put_nowait(ievent)
                     self.delete(ievent.ticket)
                     rlog(1, 'privwait', 'got response for %s' % item[0])
+                    ievent.isresponse = True
 
 class Jabberwait(Wait):
 
-    """ wait object for jabber messages """
+    """ wait object for jabber messages. """
 
     def register(self, catch, queue, timeout=15):
-        """ register wait for privmsg """
+
+        """ register wait for privmsg. """
+
         rlog(1, 'jabberwait', 'registering for %s' % catch)
         self.ticket += 1
         self.waitlist.append((catch, queue, self.ticket))
@@ -96,18 +117,23 @@ class Jabberwait(Wait):
         return self.ticket
 
     def check(self, msg):
-        """ check if <msg> is waited for """
+
+        """ check if <msg> is waited for. """
+
         for teller in range(len(self.waitlist)-1, -1, -1):
             i = self.waitlist[teller]
             if i[0] == msg.userhost:
                 msg.ticket = i[2]
                 i[1].put_nowait(msg)
                 self.delete(msg.ticket)
-                rlog(1, 'jabberwait', 'got response for %s' % i[0])
+                rlog(10, 'jabberwait', 'got response for %s' % i[0])
+                msg.isresponse = 1
 
     @locked
     def delete(self, ticket):
-        """ delete wait item with ticket nr """
+
+        """ delete wait item with ticket nr. """
+
         for itemnr in range(len(self.waitlist)-1, -1, -1):
             item = self.waitlist[itemnr]
             if item[2] == ticket:
@@ -121,13 +147,17 @@ class Jabberwait(Wait):
 
 class Jabbererrorwait(Jabberwait):
 
-    """ wait for jabber errors """
+    """ wait for jabber errors. """
 
     def check(self, msg):
-        """ check if <msg> is waited for """
+
+        """ check if <msg> is waited for. """
+
         if not msg.getType() == 'error':
             return
+
         errorcode = msg.getErrorCode()
+
         for teller in range(len(self.waitlist)-1, -1, -1):
             i = self.waitlist[teller]
             if i[0] == 'ALL' or i[0] == errorcode:
@@ -135,4 +165,4 @@ class Jabbererrorwait(Jabberwait):
                 msg.ticket = i[2]
                 i[1].put_nowait(msg)
                 self.delete(msg.ticket)
-                rlog(1,'jabbererrorwait','got error response for %s' % i[0])
+                rlog(10,'jabbererrorwait','got error response for %s' % i[0])
