@@ -11,6 +11,7 @@ from gozerbot.utils.exception import handle_exception
 from gozerbot.monitor import Monitor
 from gozerbot.config import config
 from gozerbot.eventbase import EventBase
+from message import Message
 
 class XMPPmonitor(Monitor):
 
@@ -22,9 +23,14 @@ class XMPPmonitor(Monitor):
 
         try:
             #event.fromm = event['from'] = event.to
-            e = EventBase(event)
+            e = Message()
+            e.copyin(event)
+            e.isreply = True
+            e.iscmnd = True
+            e.remotecmnd = True
+            e.remoteout = bot.jid
             e.channel = event.to
-            e.fromm = e['from'] = bot.me
+            e.fromm = e['from'] = bot.jid
             e.nick = bot.nick
             e.botoutput = True
             Monitor.handle(self, bot, e)
